Remove hip-hcc codes: Part four
Remove __HCC__, __HCC_ONLY__, __HCC_CPP__, __HCC_C__, __HCC_OR_HIP_CLANG__, __HIP_ROCclr__ and their guarded codes. Remove Hcc codes from directed_tests and samples. Remove __HIP_PLATFORM_HCC__ and __HIP_PLATFORM_NVCC__ from some files where they are not necessary. Add deprecation notice. Change-Id: I1ae467eafd749d6c25bca204c1724b026be21fce
Этот коммит содержится в:
@@ -31,10 +31,6 @@ THE SOFTWARE.
|
||||
|
||||
#include <test_common.h>
|
||||
|
||||
#ifdef __HCC__
|
||||
#include <hc.hpp>
|
||||
#endif
|
||||
|
||||
// cudaA
|
||||
|
||||
// Simple tests for variable type qualifiers:
|
||||
@@ -89,14 +85,6 @@ __global__ void vectorADD(T __restrict__* A_d, T* B_d, T* C_d, size_t N) {
|
||||
float fastZ = __sin(x);
|
||||
#endif
|
||||
|
||||
#ifdef __HCC__
|
||||
|
||||
int b = threadIdx.x;
|
||||
int c;
|
||||
|
||||
atomicAdd(&c, b);
|
||||
#endif
|
||||
|
||||
__syncthreads();
|
||||
|
||||
|
||||
|
||||
Ссылка в новой задаче
Block a user